@@ -14,7 +14,9 @@ async def upload(file: io.BytesIO, mime: str = 'image/png') -> str | None:
     with _contextlib.suppress(_aiohttp.ClientError):
         async with _aiohttp.ClientSession(connector=_aiohttp.TCPConnector(ssl=False)) as session:
             async with session.post(url='https://telegra.ph/upload', data=data) as response:
-                return f"https://telegra.ph{(await response.json())[-1]['src']}"
+                sources = await response.json()
+                if not (isinstance(sources, dict) and sources.get('error')):
+                    return f"https://telegra.ph{(await response.json())[-1]['src']}"
 
 
 async def download(url: str) -> bytes | None:
